@@ -6,7 +6,7 @@
  *
  * The GnuTLS is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
+ * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful, but
@@ -1267,6 +1267,8 @@ gnutls_ocsp_resp_get_produced (gnutls_ocsp_resp_t resp)
  *
  * Returns: On success, %GNUTLS_E_SUCCESS (0) is returned, otherwise a
  *   negative error code is returned.  
+ * 
+ * Since: 3.1.3
  **/
 int
 gnutls_ocsp_resp_check_crt (gnutls_ocsp_resp_t resp,
@@ -1832,7 +1834,7 @@ gnutls_ocsp_resp_get_certs (gnutls_ocsp_resp_t resp,
 	  goto error;
 	}
 
-      tmpcerts2 = gnutls_realloc (tmpcerts, (ctr + 2) * sizeof (*tmpcerts));
+      tmpcerts2 = gnutls_realloc_fast (tmpcerts, (ctr + 2) * sizeof (*tmpcerts));
       if (tmpcerts2 == NULL)
 	{
 	  gnutls_assert ();
